@@ -5,7 +5,7 @@
 import { getOptions, stringifyRequest } from 'loader-utils';
 import postcss from 'postcss';
 import postcssPkg from 'postcss/package.json';
-import validateOptions from 'schema-utils';
+import { validate } from 'schema-utils';
 import { satisfies } from 'semver';
 
 import CssSyntaxError from './CssSyntaxError';
@@ -31,7 +31,7 @@ import {
 export default async function loader(content, map, meta) {
   const rawOptions = getOptions(this);
 
-  validateOptions(schema, rawOptions, {
+  validate(schema, rawOptions, {
     name: 'CSS Loader',
     baseDataPath: 'options',
   });
@@ -157,6 +157,7 @@ export default async function loader(content, map, meta) {
 
   try {
     result = await postcss(plugins).process(content, {
+      hideNothingWarning: true,
       from: resourcePath,
       to: resourcePath,
       map: options.sourceMap
@@ -196,6 +197,16 @@ export default async function loader(content, map, meta) {
       importName: '___CSS_LOADER_API_IMPORT___',
       url: stringifyRequest(this, require.resolve('./runtime/api')),
     });
+
+    if (options.sourceMap) {
+      imports.unshift({
+        importName: '___CSS_LOADER_API_SOURCEMAP_IMPORT___',
+        url: stringifyRequest(
+          this,
+          require.resolve('./runtime/cssWithMappingToString')
+        ),
+      });
+    }
   }
 
   const importCode = getImportCode(imports, options);
