@@ -27,7 +27,7 @@ function removeCWD(str) {
     .replace(new RegExp(cwd, 'g'), '');
 }
 
-export default (errors, shortError) => {
+export default (errors, shortError, type) => {
   return errors.map((error) => {
     let errorMessage = error.toString();
 
@@ -35,6 +35,19 @@ export default (errors, shortError) => {
       errorMessage = errorMessage.split('\n').slice(0, 2).join('\n');
     }
 
+    if (type === 'postcss') {
+      errorMessage = errorMessage
+        .split('\n')
+        .map((str) => {
+          if (/^\(/i.test(str)) {
+            return removeCWD(str);
+          }
+
+          return str;
+        })
+        .join('\n');
+    }
+
     return removeCWD(errorMessage.split('\n').slice(0, 12).join('\n'));
   });
 };
